searchNodes=[{"ref":"FluxDatabase.html","title":"FluxDatabase","type":"behaviour","doc":"Integrate databases to Elixir projects. The main approach to integrate a database is done by defining a module which extends FluxDatabase and implements config/0 function: defmodule MyApp.Database do use FluxDatabase @impl FluxDatabase def config do [ database: :mnesia, nodes: [node()], tables: %{ user: { :user, attributes: [:id, :name, :email] } } ] end end Then, call MyApp.Database.start/0 somewhere which can start the database. It can be, for example, on your Application module: defmodule MyApp.Application do use Application @impl Application def start(_type, _args) do MyApp.Database.start() children = [ ] opts = [strategy: :one_for_one] Supervisor.start_link(children, opts) end end For more information about how to integrate and use DETS with FluxDatabase, check FluxDatabase.DETS. For more information about how to integrate and use Mnesia with FluxDatabase, check FluxDatabase.Mnesia."},{"ref":"FluxDatabase.html#c:config/0","title":"FluxDatabase.config/0","type":"callback","doc":""},{"ref":"FluxDatabase.DETS.html","title":"FluxDatabase.DETS","type":"module","doc":"DETS integration on FluxDatabase. Configuration The configuration expects a keyword list with: :database - To be :dets. :tables - A map with database definitions with {path, specification, index_key} as value and table_key as key. path - An atom with the absolute path to the table storage. specification - A keyword list with :dets.open_file/2 arguments. index_key - A string or atom defining the index key of the table. Example defmodule MyApp.Database do use FluxDatabase @impl FluxDatabase def config do [ database: :dets, tables: %{ user: { :&quot;/path/to/storage/user&quot;, [type: :set], :id }, post: { :&quot;/path/to/storage/post&quot;, [type: :set], :id } } ] end end Usage Whenever you need to use a function defined here, use it without the tables parameter and by your database module. For example, if you defined your database module as MyApp.Database, you can use: alias MyApp.Database # To start your application Database.start() # To retrieve an item from table Database.read(:user, 1) # To filter items on table Database.filter(:user, Database.all_matchspecs()) # To write an item on table Database.write(:user, %{id: 2, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}) Check the functions defined on this module for more information about how to use the functions in your database module."},{"ref":"FluxDatabase.DETS.html#all_matchspecs/0","title":"FluxDatabase.DETS.all_matchspecs/0","type":"function","doc":"Default matchspec to retrieve all items from a table using it in filter/3. Use it normally by calling from this module. Examples iex&gt; FluxDatabase.DETS.all_matchspecs() [{{:_, :&quot;$1&quot;}, [], [:&quot;$1&quot;]}]"},{"ref":"FluxDatabase.DETS.html#filter/3","title":"FluxDatabase.DETS.filter/3","type":"function","doc":"Filter items on table using :dets.select/2. Use it from your database module without tables parameter. It uses matchspecs. To get all items from your table, all_matchspecs/0 can be used. Parameters tables - A map with tables settings. More information in FluxDatabase.DETS. table_key - A string or atom with the name of the table. matchspecs - A matchspecs definition. Examples iex&gt; tables = %{user: {:&quot;/path/to/storage/user&quot;, [type: :set], :id}} ...&gt; FluxDatabase.DETS.start(tables) ...&gt; user = %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;} ...&gt; FluxDatabase.DETS.write(tables, :user, user) ...&gt; user = %{id: 2, name: &quot;John Anderson&quot;, email: &quot;neo@matrix.com&quot;} ...&gt; FluxDatabase.DETS.write(tables, :user, user) ...&gt; FluxDatabase.DETS.filter(tables, :user, FluxDatabase.DETS.all_matchspecs()) { :ok, [ %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}, %{id: 2, name: &quot;John Anderson&quot;, email: &quot;neo@matrix.com&quot;} ] }"},{"ref":"FluxDatabase.DETS.html#read/3","title":"FluxDatabase.DETS.read/3","type":"function","doc":"Retrieve an item from table using :dets.lookup/2. Use it from your database module without tables parameter. Parameters tables - A map with tables settings. More information in FluxDatabase.DETS. table_key - A string or atom with the name of the table. id - The identifier value of the item. Examples iex&gt; tables = %{user: {:&quot;/path/to/storage/user&quot;, [type: :set], :id}} ...&gt; FluxDatabase.DETS.start(tables) ...&gt; user = %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;} ...&gt; FluxDatabase.DETS.write(tables, :user, user) ...&gt; FluxDatabase.DETS.read(tables, :user, 1) {:ok, %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}}"},{"ref":"FluxDatabase.DETS.html#start/1","title":"FluxDatabase.DETS.start/1","type":"function","doc":"Open all tables using :dets.open_file/1. Use it from your database module with no parameters. Parameters tables - A map with tables settings. More information in FluxDatabase.DETS. Examples iex&gt; tables = %{user: {:&quot;/path/to/storage/user&quot;, [type: :set], :id}} ...&gt; FluxDatabase.DETS.start(tables) :ok"},{"ref":"FluxDatabase.DETS.html#write/3","title":"FluxDatabase.DETS.write/3","type":"function","doc":"Write an item on table using :dets.insert/2. It merges the new data with the data written on table before writing the new data. Use it from your database module without tables parameter. Parameters tables - A map with tables settings. More information in FluxDatabase.DETS. table_key - A string or atom with the name of the table. data - A map with the values that will be inserted on storage. Must have the index_key defined on tables settings. More information in FluxDatabase.DETS. Examples iex&gt; tables = %{user: {:&quot;/path/to/storage/user&quot;, [type: :set], :id}} ...&gt; FluxDatabase.DETS.start(tables) ...&gt; user = %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;} ...&gt; FluxDatabase.DETS.write(tables, :user, user) {:ok, %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}}"},{"ref":"FluxDatabase.Mnesia.html","title":"FluxDatabase.Mnesia","type":"module","doc":"Mnesia integration on FluxDatabase. Configuration The configuration expects a keyword list with: :database - To be :mnesia. :nodes - A list of elixir nodes definition. Should have at least one. To define only the module node, use [node()]. :tables - A map with database definitions with {table_name, specifications} as value and table_key as key. table_name - A string or atom with the name of the table. specifications - A keyword list with :mnesia.create_table/2 table definitions. Example defmodule MyApp.Database do use FluxDatabase @impl FluxDatabase def config do [ database: :mnesia, nodes: [node()], tables: %{ user: { :user, attributes: [:id, :name, :email] }, post: { :post, attributes: [:id, :title, :content] } } ] end end Usage Whenever you need to use a function defined here, use it without the tables parameter and by your database module. For example, if you defined your database module as MyApp.Database, you can use: alias MyApp.Database # To start your application Database.start() # To retrieve an item from table Database.read(:user, 1) # To match items on table Database.match(:user, %{id: :_, name: :_, email: :_}) # To write an item on table Database.write(:user, %{id: 2, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}) Check the functions defined on this module for more information about how to use the functions in your database module."},{"ref":"FluxDatabase.Mnesia.html#match/3","title":"FluxDatabase.Mnesia.match/3","type":"function","doc":"Match items on table using :mnesia.match_object/1. Use it from your database module without tables parameter. Parameters tables - A map with tables settings. More information in FluxDatabase.Mnesia. table_key - A string or atom with the name of the table. matcher - A map with ALL the keys of the table. The value defined in a key will be used to match the items. If any value should match, use :_. Examples iex&gt; tables = %{user: {:user, attributes: [:id, :name, :email]}} ...&gt; FluxDatabase.Mnesia.start([node()], tables) ...&gt; user = %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;} ...&gt; FluxDatabase.Mnesia.write(tables, :user, user) ...&gt; user = %{id: 2, name: &quot;John Anderson&quot;, email: &quot;neo@matrix.com&quot;} ...&gt; FluxDatabase.Mnesia.write(tables, :user, user) ...&gt; FluxDatabase.Mnesia.match(tables, :user, %{id: :_, name: :_, email: :_}) { :ok, [ %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}, %{id: 2, name: &quot;John Anderson&quot;, email: &quot;neo@matrix.com&quot;} ] }"},{"ref":"FluxDatabase.Mnesia.html#read/3","title":"FluxDatabase.Mnesia.read/3","type":"function","doc":"Retrieve an item from table using :mnesia.read/1. Use it from your database module without tables parameter. Parameters tables - A map with tables settings. More information in FluxDatabase.Mnesia. table_key - A string or atom with the name of the table. id - The identifier value of the item. Examples iex&gt; tables = %{user: {:user, attributes: [:id, :name, :email]}} ...&gt; FluxDatabase.Mnesia.start([node()], tables) ...&gt; user = %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;} ...&gt; FluxDatabase.Mnesia.write(tables, :user, user) ...&gt; FluxDatabase.Mnesia.read(tables, :user, 1) {:ok, %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}}"},{"ref":"FluxDatabase.Mnesia.html#start/2","title":"FluxDatabase.Mnesia.start/2","type":"function","doc":"Create and/or open all tables using :mnesia.create_table/2. Use it from your database module with no parameters. Parameters nodes - A list with node definitions. More information in FluxDatabase.Mnesia. tables - A map with tables settings. More information in FluxDatabase.Mnesia. Examples iex&gt; tables = %{user: {:user, attributes: [:id, :name, :email]}} ...&gt; FluxDatabase.Mnesia.start([node()], tables) :ok"},{"ref":"FluxDatabase.Mnesia.html#write/3","title":"FluxDatabase.Mnesia.write/3","type":"function","doc":"Write an item on table using :mnesia.write/1. It merges the new data with the data written on table before writing the new data. Use it from your database module without tables parameter. Parameters tables - A map with tables settings. More information in FluxDatabase.Mnesia. table_key - A string or atom with the name of the table. data - A map with the values that will be inserted on storage. Must have ALL keys defined on table settings. Examples iex&gt; tables = %{user: {:user, attributes: [:id, :name, :email]}} ...&gt; FluxDatabase.Mnesia.start([node()], tables) ...&gt; user = %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;} ...&gt; FluxDatabase.Mnesia.write(tables, :user, user) {:ok, %{id: 1, name: &quot;John Doe&quot;, email: &quot;john@doe.com&quot;}}"},{"ref":"changelog.html","title":"Changelog","type":"extras","doc":"Changelog"},{"ref":"changelog.html#0-0-2-2019-09-11","title":"Changelog - 0.0.2 - 2019-09-11","type":"extras","doc":"Added Add FluxDatabase behaviour on FluxDatabase __using__ macro. Add code which creates DETS table directory before opening table in FluxDatabase.DETS.start/1 pipeline."},{"ref":"changelog.html#0-0-1-2019-08-31","title":"Changelog - 0.0.1 - 2019-08-31","type":"extras","doc":"Added The project is available on GitLab and Hex. Every logger uses metadata to describe information. There are three metadata keys that can be filtered on logger settings: :flux_database_params - The params received by function. :flux_database_result - The result of the function. :error - The error result of the function. Notes Minor changes (0.0.x) from the current version will be logged to this file. When a major change is released (0.x.0 or x.0.0), the changelog of the previous major change will be grouped as a single change."},{"ref":"readme.html","title":"Flux Database","type":"extras","doc":"Flux Database Integrate databases to Elixir projects."},{"ref":"readme.html#usage","title":"Flux Database - Usage","type":"extras","doc":"Add Flux Database as a dependency in your mix.exs file: def deps do [{:flux_database, &quot;~&gt; 0.0.2&quot;}] end FluxDatabase describes how to create a module in a project to integrate databases. FluxDatabase.DETS describes how to use the DETS integration. FluxDatabase.Mnesia describes how to use the Mnesia integration."},{"ref":"readme.html#application-configuration","title":"Flux Database - Application Configuration","type":"extras","doc":"There are no application configurations. All the configuration is set by extending FluxDatabase in a module."}]